Documentation
=============

This is an affiliated package for the AstroPy package. The documentation for
this package is here:

.. toctree::
  :maxdepth: 2

  banzai/index.rst

.. note:: The layout of this directory is simply a suggestion.  To follow
          traditional practice, do *not* edit this page, but instead place
          all documentation for the affiliated package inside ``packagename/``.
          The traditional practice was intended to allow the affiliated
          package to eventually be merged into the main astropy package.
          You can follow this practice or choose your own layout.
